@@ -16,17 +16,17 @@ from ..__common__ import *
 # no __examples__ ; handled manually in tests/test_base.py
 
 
-def base100_encode(input, errors='strict'):
+def base100_encode(input, errors="strict"):
     raise NotImplementedError
 
 
-def base100_decode(input, errors='strict'):
+def base100_decode(input, errors="strict"):
     raise NotImplementedError
 
 
 if PY3:
     class Base100DecodeError(ValueError):
-        pass
+        __module__ = "builtins"
     
     def base100_encode(input, errors="strict"):
         input = b(input)
@@ -52,5 +52,5 @@ if PY3:
     
     
 add("base100", base100_encode, base100_decode, r"^(?:base[-_]?100|emoji)$", expansion_factor=1.)
-main = main(100, "<https://github.com/AdamNiederer/base100>")
+main100 = main(100, "<https://github.com/AdamNiederer/base100>")
 
